import 'dart:convert';

import 'package:apk_update/core/common/version_info.dart';
import 'package:apk_update/core/services/version_service/version_service.dart';
import 'package:flustars_flutter3/flustars_flutter3.dart';

import '../../../utils/dio_update_util.dart';
import '../../../utils/toast_util.dart';
import '../../common/constants.dart';
import '../../common/servier_api.dart';

/// 项目管理工具
class PMVersionServices implements VersionService {
  /// 域名
  final String baseUrl;

  /// 请求头
  final Map<String, dynamic>? header;

  /// 请求参数
  final Map<String, dynamic>? params;

  /// 一天提示一次升级标识
  final bool onceDay;

  const PMVersionServices({
    required this.baseUrl,
    this.params,
    this.header,
    this.onceDay = false,
  });

  @override
  Future<VersionInfo?> checkVersion() async {
    // ①版本检测
    var checkResult = await checkVersionPM();
    // ②获取版本详情
    var result = await getVersionDetailPM(checkResult?['id']);
    // 返回升级版本信息
    return VersionInfo(
      name: result['name'],
      content: result['popContent'],
      versionForce: result['forceUpgradeStatus'] == 1,
      versionPath: result['versionPath'],
    );
  }

  /// 版本检测
  Future<dynamic> checkVersionPM() async {
    var checkResult = await DioUpdateUtil.get(
        "$baseUrl${ServerApi.getLatestByProductCodePM}",
        queryParameters: params,
        headers: header);
    // 是否是最新版本提示
    final newVersion =
        int.tryParse(checkResult?['version']?.toString() ?? '') ?? 0;
    final currentVersion =
        int.tryParse(params?["currentVersion"]?.toString() ?? '') ?? 0;
    if (newVersion <= currentVersion) {
      if (!onceDay) {
        ToastUtil.showToast('已经是最新版本了！');
      }
      return null;
    }
    return checkResult;
  }

  /// 获取版本详情
  Future<dynamic> getVersionDetailPM(int? id) async {
    var detailResult = await DioUpdateUtil.get(
        "$baseUrl${ServerApi.getDetailPM}",
        queryParameters: {'id': id},
        headers: header);
    // 是否是最新版本提示
    final newVersion =
        int.tryParse(detailResult?['version']?.toString() ?? '') ?? 0;
    final currentVersion =
        int.tryParse(params?["currentVersion"]?.toString() ?? '') ?? 0;
    if (newVersion <= currentVersion) {
      if (!onceDay) {
        ToastUtil.showToast('已经是最新版本了！');
      }
      return null;
    }
    return detailResult;
  }
}
